diff libpurple/protocols/oscar/family_chat.c @ 15822:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 5fe8042783c1
children 1927f4ead3ca
line wrap: on
line diff
--- a/libpurple/protocols/oscar/family_chat.c	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/protocols/oscar/family_chat.c	Mon Mar 19 07:01:17 2007 +0000
@@ -1,5 +1,5 @@
 /*
  * Gaim's oscar protocol plugin
  * This file is the legal property of its developers.
  * Please see the AUTHORS file distributed alongside this file.
  *
@@ -80,7 +80,7 @@
 		if (conn->type != SNAC_FAMILY_CHAT)
 			continue;
 		if (!conn->internal) {
-			gaim_debug_misc("oscar", "faim: chat: chat connection with no name! (fd = %d)\n", conn->fd);
+			purple_debug_misc("oscar", "faim: chat: chat connection with no name! (fd = %d)\n", conn->fd);
 			continue;
 		}
 
@@ -172,7 +172,7 @@
 	detaillevel = byte_stream_get8(bs);
 
 	if (detaillevel != 0x02) {
-		gaim_debug_misc("oscar", "faim: chat_roomupdateinfo: detail level %d not supported\n", detaillevel);
+		purple_debug_misc("oscar", "faim: chat_roomupdateinfo: detail level %d not supported\n", detaillevel);
 		return 1;
 	}
 
@@ -501,7 +501,7 @@
 	channel = byte_stream_get16(bs);
 
 	if (channel != 0x0003) {
-		gaim_debug_misc("oscar", "faim: chat_incoming: unknown channel! (0x%04x)\n", channel);
+		purple_debug_misc("oscar", "faim: chat_incoming: unknown channel! (0x%04x)\n", channel);
 		return 0;
 	}
@@ -1,5 +1,5 @@
 /*
- * Gaim's oscar protocol plugin
+ * Purple's oscar protocol plugin
  * This file is the legal property of its developers.
  * Please see the AUTHORS file distributed alongside this file.